ams.opt.exprcalc.ExpressionCalc
===============================

.. currentmodule:: ams.opt.exprcalc

.. autoclass:: ExpressionCalc

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: _generated/

   
       
       
          ~ExpressionCalc.evaluate
       
       
          ~ExpressionCalc.get_idx
       
       
          ~ExpressionCalc.parse
       
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: _generated/

   
      ~ExpressionCalc.class_name
      ~ExpressionCalc.e
      ~ExpressionCalc.n
      ~ExpressionCalc.shape
      ~ExpressionCalc.size
      ~ExpressionCalc.v
   
   